@@ -4,12 +4,10 @@ __author__ = "neutronics material maker development team"
 
 
 import json
-import os
 import unittest
 
-import pytest
-
 import neutronics_material_maker as nmm
+import pytest
 
 
 class test_object_properties(unittest.TestCase):
@@ -26,6 +24,52 @@ class test_object_properties(unittest.TestCase):
 
         self.assertRaises(ValueError, error_raised_correctly)
 
+    def test_temperature_to_neutronics_code_openmc(self):
+        """Creates a material with a temperature and check that this can be
+        selectivly propagated to the openmc_material and that the density
+        remains unchanged"""
+
+        test_mat = nmm.Material("FLiBe", temperature_in_K=80, pressure_in_Pa=1)
+
+        assert test_mat.temperature_in_K == 80
+        assert test_mat.openmc_material.temperature == 80
+
+        test_mat_2 = nmm.Material(
+            "FLiBe",
+            temperature_in_K=80,
+            pressure_in_Pa=1,
+            temperature_to_neutronics_code=False)
+
+        assert test_mat_2.temperature_in_K == 80
+        assert test_mat_2.openmc_material.temperature is None
+        assert test_mat.openmc_material.density == test_mat_2.openmc_material.density
+
+    def test_temperature_to_neutronics_code_serpent(self):
+        """Creates a material with a temperature and check that this can be
+        selectivly propagated to the serpent_material and that the density
+        remains unchanged"""
+
+        test_mat = nmm.Material(
+            "FLiBe",
+            temperature_in_K=180,
+            pressure_in_Pa=2)
+
+        assert test_mat.temperature_in_K == 180
+        assert test_mat.openmc_material.temperature == 180
+        assert test_mat.serpent_material.split('\n')[0].endswith(' tmp 180')
+
+        test_mat_2 = nmm.Material(
+            "FLiBe",
+            temperature_in_K=180,
+            pressure_in_Pa=1,
+            temperature_to_neutronics_code=False)
+
+        assert test_mat_2.temperature_in_K == 180
+        assert test_mat_2.openmc_material.temperature is None
+        assert test_mat_2.serpent_material.split(
+            '\n')[0].endswith(' tmp 180') is False
+        assert test_mat.openmc_material.density == test_mat_2.openmc_material.density
+
     def test_density_of_material_is_set_from_equation(self):
         test_mat = nmm.Material("FLiBe", temperature_in_K=80, pressure_in_Pa=1)
         assert test_mat.density is not None
